@@ -101,7 +101,7 @@ class CatboostModel(Model):
         row_importances = []
         if df is not None:
             for _, row in df.iterrows():
-                row_df = row.to_frame()
+                row_df = row.to_frame().T
                 pred_pool = Pool(
                     row_df,
                     cat_features=row_df.select_dtypes(
